% sysmuth1.m

% *******************************************************
% This is an example of a system file which creates a 
% a dynamic model in
%
% A*y(t+1/t) = B*y(t) + C(F)*x(t/t),
%
% where C(F) = C0 + C1*F + C2*F^2 + ... + CN*F^N.
% In this expression, F 
% the forward shift operator; i.e., F*x(k/t) = x(k+1/t).
%
% The program produces the matrics
% A
% B
% C = [C0, C1,..., CN]

% It also creates some key vectors 
% lpd = Array that contains locations of predetermined 
% variables in the y vector.
% 
% ylist = Array of names of the elements of y (strings)
% xlist = Array of names of the elements of x (strings)
% ny = number of y variables
% nx = number of x variables
% nlead: Number of leads of x(t+j/t) -- (i.e., n in the above equation).


% **********************
% LISTS OF VARIABLES
% AND ASSOCIATED INDICES
% **********************

%   USER INPUT 1: Create lists and load ids
    vlstmuth1
    load imuth1


%   USER INPUT 2: Specify Location of predetetermined variables

    lpd=[iw];  

%   USER INPUT 3: Specify Length of leads in C matrices

    nlead = 0;

% **************** 
% system dimension 
% **************** 

ny=ROWS(ylist);
nx=ROWS(xlist);


% ********************************* %
% DEFINING THE MATRICES A, B AND C  %
% ********************************* %
% 

% Initialize Matrices:

A=zeros(ny,ny);
B=zeros(ny,ny);

for i=0:nlead;
eval(['CF' num2str(i) '=zeros(ny,nx);']);
end

% initialize equation list and equation number
elist=[];
eqn=0;

%   USER INPUT 4: Specify model parameters

    sigma=.1;
    alpha=.2;
    phi=4;
    b=.99;

%   USER INPUT 5: specify model equations

%   EQN1

    [elist,eqn]=ADDEQN('supply',elist,eqn);

    B(eqn,iq)=-1;
    B(eqn,iw)=sigma;

%   EQN2

    [elist,eqn]=ADDEQN('demand',elist,eqn);

    B(eqn,iq)=1;
    B(eqn,ip)=alpha;
    CF0(eqn,ix)=-1;

%   EQN3

    [elist,eqn]=ADDEQN('expectation identity',elist,eqn,10);

    A(eqn,ip)=1;
    A(eqn,iw)=-1;


% **********************
% COMBINE Ci matrices
% **********************

CF=[];
for i=0:nlead;
loc=eval(['CF' num2str(i)]);
CF=[CF loc];
end