%ssrbc.m


% Calculate steady state of model

% Features of data to match

sg=.2;   % g/y
sn=.67;  % wn/y 
sk=1-sn; % qk/y = 1 - wn/y
r=.01;   % four percent real rate per year (1% per quarter)
delta=.025; % 10 percent depreciation rate per year (2.5% per quarter)
gamma=.5;  % inverse of labor supply elasticity
sigma=1;   % intertemporal 
bstar=1/(1+r);

% choose whether to calibrate utility parameter chi 
% to hit specific labor value or whether to fix utility 
% parameter and determine particular labor value.

cal=1;

if cal==1
nbar=.2;
else
chi=5;
end

% Normalization

a=1;

% Determine other elements of steady-state from 
% Calculate capital-labor ratio
% from MPK=r+delta

knratio=((a*sk)/(r+delta))^(1/(1-sk));

% Calculate the real wage rate

wss=a*sn*(knratio^sk);

% Calculate the ratio of output to labor input

ynratio=a*(knratio^sk);

% Calculate the ratio of consumption to labor input

cnratio=(1-sg)*ynratio-delta*knratio;

% The requirement that 
% w-(mun)/muc=chi*(n^gamma)*(c^sigma)
% now is "one equation in one unknown" given the
% information above since the rhs is
% chi*(n^(gamma+sigma))*(cnratio^sigma)
% We can use it to "calibrate" the labor preference 
% parameter chi given a specified value of nbar or
% to "calculate" the ss level of labor given 
% a particular chi value.

if (cal==1)
    denom=(nbar^(gamma+sigma))*(cnratio^sigma);
    chi=(wss/denom);
    nss=nbar;
else    
    nss=(wss/(chi*(cnratio^sigma)));
    ns=ns^(1/(gamma+sigma));    
end

css=cnratio*nss;
yss=a*(knratio^sk)*nss;
kss=knratio*nss;
lamss=css^(-sigma);
pss=lamss;
lss=1-nss;
omss=wss*pss;

% Checking 4 nonlinear equations at these parameter values

gap=zeros(4,1);

gap(1)=(css^(-sigma))-lamss;
gap(2)=chi*nss^gamma-lamss*wss;
gap(3)=bstar*lamss*(a*sk*((nss/kss)^sn)+(1-delta)) - lamss;
yss2=a*(kss^sk)*(nss^sn);
gap(4)=(1-sg)*yss2+(1-delta)*kss-kss-css;

disp('Equation gaps for calibrated model')
disp(gap')

x=[lamss kss css chi];

disp('solutions for [lamss kss css chi]');
disp(x)


% Calculate derivative information
derivinfo

% Save ss values

save ssrbc.mat css nss lss yss kss pss lamss omss