%  crashsys1.m

% ***********************************************************************
% The model is written as:
%
% A*y(t+1/t) = B*y(t) + C(F)*x(t/t),
%
% where C(F) = C0 + C1*F + C2*F^2 + ... + CN*F^N, where F is defined as the
% forward shift operator; i.e., F*x(k/t) = x(k+1/t).
%
% Output parameters:
% A
% B
% C = [C0, C1,..., CN]
% LPD = Array that contains locations of predetermined variables in the
%       y vector.
% 
% YLIST = Array of names of the elements of y (strings)
% XLIST = Array of names of the elements of x (strings)
% ny: Number of elements of y
% nx: Number of elements of x
% nlead: Number of leads of x(t+j/t) -- (i.e., n in the above equation).
% np: number of predetermined variables


% **********************
% LISTS OF VARIABLES
% AND ASSOCIATED INDICES
% **********************

ylist=['y1 '
       'y2 '];

xlist=['x'];

iy1=1;
iy2=2;
ix=1;

disp('Cases ')
disp('(1) uniquely solvable')
disp('(2) multiple equilibria')
disp('(3) nonexistence: number of roots')
disp('(4) nonexistence: rank condition')
disp(' ')
cs=input('Choose case')

mu1=.8;
c1=1;
c2=2;

if cs==1
  lpd=[1];
  mu2=1.2;
elseif cs==2
  lpd=[2];
  mu2=.9;
elseif cs==3
  lpd=[1 2];
  mu2=1.2;
elseif cs==4
  lpd=2;
  mu2=1.2;
else
  disp('case choice out of range')
end
  

% **************** 
% system dimension 
% **************** 

ny=rows(ylist);
nx=rows(xlist);
nlead=0;

% ********************************* %
% DEFINING THE MATRICES A, B AND C  %
% ********************************* %
% 
% -----------------------------------------------
% Equations are written in the form
% A*Ey(t+1)|I(t) = B*Ey(t)|I(t) + C(F)*Ex(t)|I(t)
% where C(F) = C0 + C1F + ... + CnF^n
% -----------------------------------------------


% Initialize Matrices:

A=zeros(ny,ny);
B=zeros(ny,ny);
CF=zeros(ny,nx); 
elist=[];
eqn=0;

% EQN1

[elist,eqn]=ADDEQN('first',elist,eqn);

A(eqn,iy1)=1;
B(eqn,iy1)=mu1;
C(eqn,ix)=c1;

% EQN2

[elist,eqn]=ADDEQN('second',elist,eqn);

A(eqn,iy2)=1;
B(eqn,iy2)=mu2;
C(eqn,ix)=c2;
