function [FACV]=FDFKW(M,PI,G,Vii,lags,ch,pts)

% create the autocovariances of filtered states, using a frequency domain
% approach.  The underlying model is 

% s(t)=M s(t-1)+ G e(t)
%
% y(t)=PI*s(t)
%
% and the program inputs therefore include M, PI, G and V=E(e(t)*e(t)')
% The program also specifies the lags at which to compute the 
% autocovariances of the filtered states, as well as the number of points
% to be used in approximating the Fourier integral.

dos('del fdfkw.mat')
t1=clock;

% specify lags for filter autocovarieances

nlags=max(size(lags));

% determine size of M matrix

nM=max(size(M));

% identity matrix of size of M

if (max(size(M))==1)
 IM=1;
else
 IM=eye(size(M));
end

% number of points at which Fourier transform is evaluated: 2*m

if (nargin <7)
  m=200;
else
  m=pts;
end

disp([num2str(m),' points used in Fourier integral approximation'])

% set grid for omega in evaluating spectral density, etc.

bnd=-1+(1/(2*m));
om=bnd:(1/m):-bnd;    clear bnd;
om=om*pi;

% define imaginary number
im=sqrt(-1);

if (nargin<6);
    sel=1;
    disp('No filter specified')
    disp(' ')
end

% Compute the transfer function of the selected filter

FILTTF

disp('computing power spectrum of filtered states')
disp('  ')
disp('  ')
nom=max(size(om));

FSACV=zeros(nM,nM*(nlags+1));

blags=[0 lags];

for j=1:nom;
  % compute power spectrum of s at the discretization point
  temp = inv(exp(im*om(j))*IM-M)*G;
  FSD = ftfil(j)*(temp*Vii*temp')/(2*pi);

% The matrix FSD now contains matrix power spectrum for the filtered
% states at the point of interest
 
% Create lag vector

  temp=(exp(im*om(j)*blags));

 % Weight by length of approximating segments to obtain
 % approximation to integral:

 temp=temp*(pi/m);
 
 new=kron(temp,FSD);
 
  % put this in the relevant spot
 FSACV=FSACV+new;

end; 

% compute the acv term for the filtered variables:')

rPI=size(PI);
rPI=rPI(1); % number of rows in the PI matrix

FACV=zeros(rPI,rPI*(nlags+1));

PIP=PI';

for j=0:nlags
  FACV(:,j*rPI+1:(j+1)*rPI)=real(PI*FSACV(:,j*nM+1:(j+1)*nM)*PIP);
end

t2=clock;
tm=etime(t2,t1);


save fdfkw.mat FACV lags 

disp(['computations completed by FDFKW.m'])
disp(['elapsed time = ' num2str(tm) ' seconds'])