% FILTTF.m
%
% Optionally select filter 
% and compute the transfer function
% 

if (sel==1)
    
disp('Select Filter:')
disp(' 0 = No Filter')
disp(' 1 = First Difference')
disp(' 2 = Exact Bandpass')
disp(' 3 = Approximate Bandpass')
disp(' 4 = Hodrick Prescott')
disp(' 5 = Truncated Hodrick-Prescott')

ch=input('Selection = ')

end

if (ch==0)
  % No Filter
  ftfil=ones(size(om));

  if (sel==1)
    plot(om/pi,ftfil),title('transfer function of null filter')
    pause
    close
  end
  
elseif (ch==1)
% First Difference Filter
  ftfil=ones(size(om))-exp(-im*om);
  ftfil=abs(ftfil).^2;
  if (sel==1)
    plot(om/pi,ftfil),title('transfer function of first difference')
    pause
    close
  end
elseif (ch==2)
% Exact Bandpass Filter

% Period corresponding to upper cutoff frequency
% updc=2 makes this a high pass filter (since period = 2 implies om=pi).
updc=6;
% Period corresponding to lower cutoff frequency
lpdc=32;
% Implied Frequencies
omubar=2*pi/updc;
omlbar=2*pi/lpdc;

top=abs(om)>omubar; % high frequencies
bot=abs(om)<omlbar; % low frequencies
ftfil=ones(size(om))-top-bot;

if (sel==1)
  plot(om/pi,ftfil),title('transfer function of exact bandpass')
  pause
  close
end

elseif (ch==3)

% Approximate Bandpass Filter

% Period corresponding to upper cutoff frequency
% updc=2 makes this a high pass filter (since period = 2 implies om=pi).
updc=6;
% Period corresponding to lower cutoff frequency
lpdc=32;
% Implied Frequencies
omubar=2*pi/updc;
omlbar=2*pi/lpdc;

% To construct a low pass filter, with a cutoff frequency of "ombar",
% we note that the transfer function of the approximating filter
% is given by:
%
%  alpha(om) = a0 + a1 cos(om) + ... aK cos(K om)
%
% and the ak's are given by:
%  
% a0 = ombar/(pi)
% 
% ak = sin(k ombar)/(k pi)
%
% where ombar is the cutoff frequency.

% We employ the fact that a bandpass filter is the difference between two 
% low pass filters,
%   bp(L) = bu(L) - bl(L)
% with bu(L) being the filter with the high cutoff point and bl(L) being 
% that with the low cutoff point.

% set number of leads/lags
K=32;

% Construct Filter Weights

akvec=zeros(1,K+1);

akvec(1)=(omubar-omlbar)/(pi);

for k=1:K;
akvec(k+1)=(sin(k*omubar)-sin(k*omlbar))/(k*pi);
end

% Impose constraint that transfer is zero at om = 0 
% This amounts to requiring that weights sum to zero.
% Initial sum of weights:
lam=akvec(1)+2*sum(akvec(2:K+1));
% amount to add to each weight to get sum to add to zero
lam=-lam/(2*K+1);
akvec=akvec+lam;

ftfil=akvec(1)*ones(size(om));
for k=1:K;
 ftfil=ftfil+akvec(k+1)*2*cos(om*k);
end
ftfil=ftfil.^2;

if (sel==1)
  plot(om/pi,ftfil),title('transfer function of app bp filter')
  pause
  close
end

elseif (ch==4)
% HPFilter
% Compute the transfer function
lam=1600;
ftfil=(4*lam*(1-cos(om)).^2)./(1+4*lam*(1-cos(om)).^2);

if (sel==1)
  plot(om/pi,ftfil),title('transfer function of Hodrick-Prescott filter')
  pause
  close
end

elseif(ch==5)

hpfilt=(4*lam*(1-cos(om)).^2)./(1+4*lam*(1-cos(om)).^2);

% Truncated HP filter used in KR's "Low Frequency Filtering" paper

% Treat this as a 103 element moving average.  Compute the transfer 
% function by evaluating this moving average at all points on the grid.
maxf=51;

% disp('constructing lag weights of truncated HP filter')

% Construction of Lag Weights

FILT(maxf+1)=1-((.894^0)*(.0561*cos(.112*0) + .0558*sin(.112*0)));
for j=1:maxf;
   FILT(maxf+1-j)=-(.894^j)*(.0561*cos(.112*j) + .0558*sin(.112*j)); % change
   FILT(maxf+1+j)=FILT(maxf+1-j);
end;

% disp('constructing Transfer Function of Truncated HP Filter')

% Construction of Transfer Function

filt=zeros(1,2*m);

for j=-maxf:1:maxf;
    filt=filt+FILT(maxf+1+j)*(exp(-im*om*j));
end

ftfil=abs(filt).^2;

if (sel==1)

  plot(om/pi,ftfil),title('transfer function of truncated Hodrick-Prescott')
  pause
  close
end

else
 disp('inadmissable choice filter choice')
 pause
end
