function pparms=pltkw(IR,ylist,xlist,opparms,fst);

% Matlab File: plotkw.m

% Program to design and redesign plots of impulse responses

% symbol ordering
sym=['x','o','+','*','d','^'];

nir=rows(IR);
nvar=rows(IR)-1;
dt=IR(:,1);
zz=zeros(1,nir);

b=max(cols(xlist),cols(ylist));

% create a set of blanks the width of the larger of xlist, ylist
blnk=[];
for i=1:b;
   blnk=[blnk, '     '];
end

plsz=0;

if (nargin<4)
   clc
   disp(' ')
   disp(' ')
   disp('PLTKW.m: creating new plot')
   disp('if you want to redesign an old plot,')
   disp('you must specify plot parameters as fourth argument')
   disp(' ')
   disp(' ')
   while plsz==0
      m=input('Number of rows of subplot ');
      n=input('Number of columns of subplot ');
      nvp=input('largest number of variables in any subplot (max=6) ');
      disp(' ')
      disp(['You chose: rows=',num2str(m), ' cols=', num2str(n), ' vars=',num2str(nvp)])
      disp(' ')
      disp('If this is correct choose 1 to continue setting up the plot')
      disp('To revise the plot size, select 0') 
      disp(' ')
      plsz=input('proceed(1) or revise(0) ');
   end
   clc
   
   
   pparms=zeros(n*m+1,6);
   pparms(1,1:3)=[m n nvp];

   ny=rows(ylist);   
   nx=rows(xlist);
   
   for i=1:1:ny;
      sylist(i,:)=[sprintf('%3.0f',i), ' ', ylist(i,:)];
   end
   
   for i=1:1:nx;
      sxlist(i,:)=[sprintf('%3.0f',i+ny), ' ', xlist(i,:)];
   end

   clist=[sylist
      sxlist]; 
   if ny+nx>30
      disp('there are more than 30 elements in [y x]')
      disp('list being printed to pltkw.out')
      dos('del pltkw.out');
      diary pltkw.out
      sylist
      sxlist
      diary off
   else
      disp('There are less than 30 elements in [y x]')
   end
   
   ind=1;
   
   for j=1:m; % row indicator
      for k=1:n; % column indicator       
       disp(['Creating the ',num2str(j),',',num2str(k),'th subplot'])
       disp(['out of a ', num2str(m),' by ',num2str(n),' matrix of subplots'])
       if (ny+nx<=30)
         disp(['The composite variable list contains ', num2str(nvar), ' elements'])
         disp(['The first ', num2str(ny),' elements are endogenous variables y(t)'])
         disp(sylist)
         disp(' ')
         disp(['The next ', num2str(nx),' elements are exogenous variables x(t)'])
         disp(sxlist)
       else
          disp('Consult printed list for variable selections')
       end
       disp(' ')
       disp(' ')
       disp(['Select up to ',num2str(nvp) ' variables to include in subplot'])
       disp('enter single variable (as 4) or vector (as [4 1 6])')
       disp(' ')
       disp('variable ordering affects symbol used in plot')
       disp('Symbols are ordered: x o + * diamond(d) triangle(^)')
       ch=0;
       disp(' ')
       while ch==0
          loc=input('Input the variables for the subplot: ');
          disp(' ')
          if cols(loc)==1
             disp(['You chose: ', clist(loc,cols(clist))])
          else
             disp('You chose the following variables in the following order:')
             disp([clist(loc,cols(clist))])
          end
          disp('  ')
          disp('If this is correct choose 1 to set up the plot')
          disp('To revise the plot specification, select 0') 
          disp(' ')
          ch=input('setup(1) or revise(0)' );
       end 
       clc
       if (ind==1)
        disp(' ')
        disp(' ')
        disp(' ')
        disp('For the first subplot, the figure will appear on the screen')
        disp('Minimze it and then proceed with other subplots')
        disp('Do not hit return when the figure is on the screen')
        disp(' ')
        disp('strike any key to continue to first subplot')
        pause
       end
    
       pparms(ind+1,1:cols(loc))=loc;
       ttl=[];
       if cols(loc)==1
          ttl=clist(loc,4:cols(clist));   
       else
         for kk=1:cols(loc);
            ttl=[ttl, ['  ',clist(loc(kk),4:cols(clist)),' (',sym(kk),')']];
         end
       end
       subplot(m,n,ind),...
          hold on
			 for kk=1:cols(loc);
   			plot(dt,zz,'-',dt,IR(:,loc(kk)+1),sym(kk),...
      		dt,IR(:,loc(kk)+1),'-'),...;
			 end
          title(ttl),xlabel('                           date');
          hold off
        ind=ind+1;
      end % for k
   end % for j
 
elseif (nargin<5) % edit an preexisting subplot 
    
   pparms=opparms;
   
   m=pparms(1,1);
   n=pparms(1,2);
   nvp=pparms(1,3);
   
   ny=rows(ylist);   
   nx=rows(xlist);
   
   for i=1:1:ny;
      sylist(i,:)=[sprintf('%3.0f',i), ' ', ylist(i,:)];
   end
   
   for i=1:1:nx;
      sxlist(i,:)=[sprintf('%3.0f',i+ny), ' ', xlist(i,:)];
   end

   clist=[sylist
      sxlist];  

     
   disp('PLTKW.m: editing an existing plot')
   disp(' ')
   disp(' ')
   disp(['Your plot has: rows=',num2str(m), ' cols=', num2str(n)])
   disp(' ')
   disp(['The current maximum number of variables per plot=',num2str(nvp)])
   nvp=input('Input a new maximum for the plot revision =');
   clc
   disp('The current matrix of subplots is structured as follows: ')
   disp(' ')
   
   ptab=[];
   for jj=1:1:m;
    for kk=1:1:n;
       new=['subplot: ',sprintf('%3.0f',jj) sprintf('%3.0f',kk), '   Variables: '];
       loc=pparms((jj-1)*n+kk+1,:);
       ploc=loc>0;
       loc=loc(ploc);
       ploc=sum(ploc);       
       for ll=1:ploc;
         new=[new,clist(loc(ll),5:cols(clist)),'(',sym(ll),')'];
       end
       for ll=ploc+1:nvp;
          new=[new,blnk(1:b+3)]; % assumption is that symbol width is 1
       end
      ptab=[ptab
         new];
      end % kk
   end % jj
   
   disp(ptab)
   disp(' ')
   disp('where y(o) means that variable y will be plotted with o symbol, etc.')
   disp(' ')
   disp(' ')
   disp('strike any key to continue')
   pause    
   disp('This translates to the existing plot parameters:')   
   disp(pparms)
   disp(' ')
   disp('strike any key to continue')
   pause
               
   plt=input('plot to screen for current parameter values? 1 for yes ');
   
   if plt==1
      disp('When the figure has been constructed, you should print it if you want a copy')
      disp('when you hit return, it will be closed, and you will start editing')
      disp('Strike any key to see plot for current parameter values')
      pause
      
       ind=1; 
   
 			for j=1:m;
     			for k=1:n;
               loc=pparms(ind+1,1:nvp);
               loc=loc(loc>0);
               ttl=[];
       			if cols(loc)==1
          			ttl=clist(loc,4:cols(clist));   
       			else
         			for kk=1:cols(loc);
            		ttl=[ttl, ['  ',clist(loc(kk),4:cols(clist)),' (',sym(kk),')']];
         		end % endif
       	   end % endfor
       		subplot(m,n,ind),...
          		hold on
			 			for kk=1:cols(loc);
   						plot(dt,zz,'-',dt,IR(:,loc(kk)+1),sym(kk),...
      					dt,IR(:,loc(kk)+1),'-'),...;
			 			end
          			title(ttl),xlabel('                           date');
          			hold off
        			ind=ind+1;
      		end % for k
         end % for j
         pause
         close
    	end % optional plt 
   
   ed=1;
   
   while ed==1    
   chh=0;
   while (chh==0)
      nwi=0;
      while nwi<1
       ind=input('select subplot--identified as (row,column) entry--using the form [r c]: ');
       nwi=sum(ind<=[m n])/2;
      end      
          
      disp(['Editing the ',num2str(ind),' subplot'])
       disp(' ')
       disp(['within a ', num2str(m),' by ',num2str(n),' matrix of subplots'])
       disp(' ')
      chh=input('choose 1 to continue, 0 to revise choice of subplot ');
    end
      r=ind(1); c=ind(2);
      ind=((r-1)*n)+c; % convert to matlab indexing system          
      if (ny+nx<=30)
         clc
         disp(' ')
         disp(['The composite variable list contains ', num2str(nvar), ' elements'])
         disp(['The first ', num2str(ny),' elements are endogenous variables y(t)'])
         disp(sylist)
         disp(' ')
         disp(['The next ', num2str(nx),' elements are exogenous variables x(t)'])
         disp(sxlist)
       else
          disp('Consult printed list for variable selections')
       end % endif
       disp(' ')       
       loc=pparms(ind+1,1:nvp);
       loc=loc(loc>0);              
          if cols(loc)==1
             disp(['The existing variables in this subplot are: ', clist(loc,cols(clist))])
          else
             disp('The existing variables in this subplot are:')
             disp([clist(loc,cols(clist))])
          end
       disp(' ')
       disp(['Select up to ',num2str(nvp) ' alternative variables to include in subplot'])
       disp('enter single variable (e.g. 4) or vector (e.g. [4 1 6])')
       disp(' ')
       disp('variable ordering affects symbol used in plot')
       disp('Symbols are ordered: x o + * diamond(d) triangle(^)')
       ch=0;
       disp(' ')
       while ch==0
          loc=input('Input the alternative variables for the subplot: ');
          disp(' ')
         if cols(loc)==1
             disp(['You chose: ', clist(loc,cols(clist))])
          else
             disp('You chose the following variables in the following order:')
             disp([clist(loc,cols(clist))])
          end
          disp('  ')
          disp('If this is correct choose 1 to set up the plot')
          disp('To revise the subplot specification over again, select 0') 
          disp(' ')
          ch=input('setup(1) or revise(0) ');
       end 
       clc
       pparms(ind+1,:)=zeros(1,6);
       pparms(ind+1,1:cols(loc))=loc;
       ttl=[];
       if cols(loc)==1
          ttl=clist(loc,4:cols(clist));   
       else
         for kk=1:cols(loc);
            ttl=[ttl, ['  ',clist(loc(kk),4:cols(clist)),' (',sym(kk),')']];
         end
       end
      
       subplot(m,n,ind) % initialize subplot
       subplot(m,n,ind),...
          hold on
			 for kk=1:cols(loc);
   			plot(dt,zz,'-',dt,IR(:,loc(kk)+1),sym(kk),...
      		dt,IR(:,loc(kk)+1),'-'),...;
			 end
          title(ttl),xlabel('                           date');
          hold off
          close
          clc
          disp(['Editing of subplot ',num2str(jj),',',num2str(kk),' completed'])
        ed=input('Edit another? 1 for yes ');
     end % ed while
   fst=1;
else % if nargin=5
   pparms=opparms
end

if (fst==1)   
% direct plotting of existing parameter set
      disp('Plotting an existing (new or revised) parameter set')
      pause(2)   
   m=pparms(1,1);
   n=pparms(1,2);
   nvp=pparms(1,3);
   
   ny=rows(ylist);   
   nx=rows(xlist);
   
   for i=1:1:ny;
      sylist(i,:)=[sprintf('%3.0f',i), ' ', ylist(i,:)];
   end
   
   for i=1:1:nx;
      sxlist(i,:)=[sprintf('%3.0f',i+ny), ' ', xlist(i,:)];
   end

   clist=[sylist
      sxlist];
   ind=1; 
   
 for j=1:m;
     for k=1:n;
       loc=pparms(ind+1,1:nvp);
       ttl=[];
       loc=loc(loc>0);
       if cols(loc)==1
          ttl=clist(loc,4:cols(clist));   
       else
         for kk=1:cols(loc);
            ttl=[ttl, ['  ',clist(loc(kk),4:cols(clist)),' (',sym(kk),')']];
         end
       end
      
       subplot(m,n,ind),...
          hold on
			 for kk=1:cols(loc);
   			plot(dt,zz,'-',dt,IR(:,loc(kk)+1),sym(kk),...
      		dt,IR(:,loc(kk)+1),'-'),...;
			 end
          title(ttl),xlabel('                           date');
          hold off
        ind=ind+1;
      end % for k
   end % for j
   disp('  ')
   disp('  ')
   disp('Pltkw.m: plotting completed, parameters returned as pparms')
   end

