% FACVSKW.m

disp('  ')
disp('  ')
disp('  ')
disp('FACVSKW.m: This program allows the user')
disp('to retrieve individual elements of the')
disp('filtered autocovariance generating function')
disp('or to produce a basic table of moments')
disp('  ')
ld=input('Optionally load FACV from FDFKW.mat? 1 for yes ')

if (ld==1)
 load FDFKW
 disp('FDFKW.mat loaded')
else 
 disp('Computing new results')
 lags=input('input lags (e.g., lags = 1 2 4 8 12]')
 FACV=FDFKW(M,PI,G,Vii,lags);
end

disp('The lags available are: ')
lags
disp('if does not include the lags that you want,')
disp('then you must re-run this program')
nlags=length(lags);

pause(1)

% *******************************************************
% Tables option
% *******************************************************

disp('  ')
opt=input('Choose task: (1) Table or (2) Selected Correlations ');
disp(' ')

if (opt==1)

if (COLS(ylist)==COLS(xlist))
 list=[ylist
      xlist];
else
 list=ylist;
 disp('xlist has different number of columns from ylist')
 disp('ylist is used by itself')
 disp('run [ylist,xlist]=MAKEID(ylist,xlist,...)')
 disp('to generate ylist,xlist with same column dimension')
 disp(' ')
end
  
% reference variable selection

NUMLIST(list);

disp(' ')

r=input('choose reference variable : ');
disp(' ')
disp(['reference variable is ' list(r,:)])
disp('strike any key to continue')
pause
clc

% variable ordering selection

disp('the default ordering is given in the table')
NUMLIST(list);
disp(' ')
disp('You can select a subset of variables or change the ordering')

ed=input('select/change: 1 for yes, 0 for no ');
disp(' ')

if (ed==1)
 disp('input a new vector in form: [1 2 3 ....] ')
 disp('the number of elements is up to you ')
 disp('but the reference variable must be included first')
 ord=input('ordering/selection vector: ')
else
 disp('default ordering chosen')
 ord=1:ROWS(list);
end
clc

rPI=ROWS(PI);

% Compute the standard deviations of the variables:

sd = sqrt(diag(FACV(1:rPI,1:rPI)));
tcorr=kron(sd,sd');

% Create relative volatility measure by dividing through by the
% standard deviation of reference variable

sdr = sd/sd(r);

TAB = [sd sdr];

% Compute Correlation Matrix of Variables:

% Operate on tcorr to avoid division by zero in next step

for i=1:rPI,
 for j=1:rPI,
    if tcorr(i,j)==0,
       tcorr(i,j)=1;
  end
 end
end

CR=FACV(1:rPI,1:rPI)./tcorr;

% CORRELATIONS WITH REFERNCE VARIABLE

CC=CR(1:rPI,r);

% CROSS CORRELATIONS WITH REFERENCE VARIABLE:

for j=1:nlags;
 TEMP=FACV(:,j*rPI+1:(j+1)*rPI)./tcorr;
 CC=[CC TEMP(r,1:rPI)'];
 CC=[TEMP(1:rPI,r) CC];
end

% AUTOCORRELATIONS 

AC=[];

for j=1:1:nlags;
 TEMP=FACV(:,j*rPI+1:(j+1)*rPI)./tcorr;
 AC=[AC diag(TEMP)];
end

TAB=[TAB AC CC];

% Select and reorder the variables

RTAB=TAB(ord,:);

rlist=list(ord,:);

tabprint

diary facvskw.out

disp('Standard deviations and relative standard deviations')
disp([rlist num2str(RTAB(:,1:2))])
disp(' ')
disp(' ')
pause

zip=COLS(rlist);
zip=32*(ones(1,zip));
zip=char(zip);
rlist =[zip
        rlist];
    
disp('Autocorrelations')
TEMP=[lags
      AC(ord,:)];
disp([rlist num2str(TEMP)]);
pause
disp(' ')
disp(' ')

down=nlags:-1:1;
cxvec=[-lags(down) 0 lags];
TEMP=[cxvec
      CC(ord,:)];
  
disp(['Crosscorrelations with ',rlist(2,:)])
disp([rlist num2str(TEMP)]);
disp(' ')
disp(' ')  
diary off
disp('Standard Table is in facvs.txt')

opt=input('Look at Selected Correlations? 1 for no and 2 for yes')

end

if (opt==2)

% *******************************************************
% Selected correlations option
% *******************************************************

facvskwsc

end