% debugkw.m

% eval(system)

opt=5;

while opt~=0;

disp('Select the following debugging option')
disp('  ')
disp('   (0) quit')
disp('   (1) check for rows of zeros in [A B]')
disp('   (2) check for det(Az-B) nonzero graphically')
disp('   (3) check LR multipliers')
disp('   (4) check # stable roots versus # predetermined variables')
disp('   (5) check equations of the model')
disp(' ')
opt=input('choose option: ');
clc

if (opt==1)
% Check 1:

tolz=10^(-6);

disp('Checking for rows of zeros in [A B]')
disp(' ')

% Check for rows of zeros in [A B]

[sa1 sa2]=sort(max(abs([A B]')));

% sa1 contains the absolute value of the biggest
% element of each row A.

% sa2 contains indices that sort these from lowest to highest.

% determine location and number of rows of A with effectively zero elements

lz=(sa1<tolz);  
nz=sum(lz);
rz=sa2(lz);

disp(['Number of zero rows in [A B] is ', num2str(nz)])
disp('with zero being defined as less than tolz = 10^(-6)')
disp(' ')
if (nz>0)
 disp('The zero rows are: ')
 disp(rz')
end 

elseif (opt==2)
% **************************************************************************
% Checking the necessary condition |Az-B| nonzero                   *
% **************************************************************************

disp('Checking for |Az-B| non zero on z=(-10, 10)')
disp('which can be time consuming in large systems')
disp(' ')

t=1;
for z=-10:1/4:10
	h(t)=z;
	polyn(t)=det(A*z-B);
t=t+1;
end
if polyn==0
 disp('  ')
 disp('Necessary condition for Solvability violated: |Az-B|=0')
 disp('strike any key to continue')
 pause
else
 disp('  ')
 disp('Necessary condition for Solvability satisfied: |Az-B| not = 0')
 disp('strike any key to continue')
 pause
end

plot(h,polyn),title('Test of determinant '),xlabel('z'),ylabel('|Az-B|')
pause
close
elseif (opt==3)
   
% **************************************************************************
% Determining the long-run effects of x on y in system *
% **************************************************************************
									  %*
if rank(A-B)==cols(A)                                                      %*    
 LR=zeros(ny,nx);                                                         %*
 for i=0:1:nlead                                                          %*
  LR=LR+CF(:,i*nx+1:(i+1)*nx);                                            %*
 end                                                                      %*
 LR=(A-B)\LR; 
 !del debugr.out
 diary debugr.out
 disp('Long Runs Effects from Original System')                           %*
 disp('long run effect of x(j) on y(i) is (i,j) element')                 %*
 disp(LR)                                                                 %*
 disp(' ')
 disp('results saved debugr.out')
else
 disp('(A-B) is rank deficient: multipliers not computed')
end                                                                       %*

elseif (opt==4)

x=eig(B,A);  % compute generalized eigenvalues |Az-B|=0.

inflv=input('choose a power of 10 to test for effectively infinite eigenvalues ');
      % critical value: a root is zero if it is less than 10^-inflv


% We are interested in the the nature of the solutions to |Az-B|=0: 
% How many are infinite, how many finite but unstable, how many are stable 

% For computational reasons, though, we look at the reciprocal solutions,
% i.e., the solutions to |Bz-A|=0.  

ev=eig(A,B);   % solutions to |Bz-A|=0, i.e., the reciprocals to the 
					% the generalized eigenvalues that we are used to thinking about.          

aev=abs(ev);   % absolute value of eigenvalues


     
% find the small solutions to |Bz-A|=0, i.e., the infinite solutions to |Az-B|=0.
ninf=sum(aev<10^-inflv); 
lfin=ones(size(aev))-(aev<10^-inflv);  % location of finite eigenvalues

flip=aev(logical(lfin));
flip=ones(size(flip))./flip;  % finite eigenvalues to |Az-B|=0

nus=sum(aev<.9999); % number of unstable eigenvalues to |Az-B=0
							% i.e., the solutions to |A-Bz|=0 that are just less than 1

ns=sum(aev>=.9999);

% 
nzev=ny-nus-ns;     % test for zero evs to |Az-B|=0, which show up as NaN 
						  % solutions to |A-Bz|=0.  Example: a=1, b=0, z=a/b=NaN.
nus=nus-ninf;

npd=sum(ones(size(lpd)));
disp(' ')
disp(' ')
disp('Based on generalized eigenvalue analysis:')
disp(' ')
disp(['Number of infinite eigenvalues       (nf)  = ',num2str(ninf)])
disp(['Number of other unstable eigenvalues (nus) = ',num2str(nus)])
disp(['Number of stable eigenvalue          (ns)  = ',num2str(ns)])
disp(['Number of predetermined variables    (npd) = ',num2str(npd)])
disp(' ')
disp('this last entry may miss zero stable evs')
disp(['The above suggests ',num2str(nzev),' zero eigenvalues'])
pause

rept=input('Report generalized eigenvalues (roots of Az-B)? 1 for yes, 0 for no');
if (rept==1)
    disp('Generalized eigenvalues and modulus')
    gev=eig(B,A);
    disp([gev abs(gev)])
end

sys=input('Compare eigenvalues before and after reduction? enter 1 for yes');
if sys==1
disp('System reduction analysis:')

track=1;
[nd,nf,AN,BN,reord,CF]=REDKW(A,B,CF,nx,lpd,track);
clc

ew=eig(BN(nf+1:ny,nf+1:ny));
aew=abs(ew);

sflip=sort(flip);
sflip=[sflip(nus+ns+1:max(size(flip)))
       sflip(1:nus+ns,1)];
disp('Finite eigenvalues (in modulus)')
disp('before and after reduction:')
disp([sflip sort(aew)])
disp(' ')
disp('strike any key to continue')
pause
end

elseif (opt==5)
   clc
diary on

disp('NOTE:  This equation checker will work correctly IFF the entries in your  ')
disp('       variable list are ordered exactly as you have numbered your variables. ')
disp('       You will need to have your A, B, and CF matrices in memory, along ')
disp('       with your lists of variable names and shock names.')
disp(' '); disp(' ')

i = input ('What is your list of variables called?   ','s');
j = input ('What is your list of shocks called?      ','s');
disp('  ')
eval(['list =' i ';' ]) 
eval(['mist =' j ';'])

eqnbugs(A,B,CF,list,mist)
diary off

disp('NOTE:   If your list of equations is terribly long, you may wish to view the diary file.')
disp(' ');

elseif (opt~=0)
   disp('Make a new selection that is between 0 and 5') 
end

end
